import 'package:flutter/material.dart';

import 'environment_manager.dart';
import 'environment_type.dart';

class EnvironmentIndicatorWidget extends StatelessWidget {
  EnvironmentIndicatorWidget({
    this.child,
  });

  final Widget child;

  @override
  Widget build(BuildContext context) {
    return StreamBuilder(
      stream: (EnvironmentManager().environmentChangedListener),
      builder: (BuildContext context, _) {
        Map<String, EnvironmentType> environmentTypeMap = EnvironmentManager().currentEnvironment;

        if (environmentTypeMap['all'] == EnvironmentType.product && EnvironmentManager().isNeedRestart) {
          return child;
        }

        List<Widget> widgetList = [];

        for (final name in environmentTypeMap.keys) {
          widgetList.add(
            Text(
              '$name: ${englishDescribeEnvironment(environmentTypeMap[name])}',
              style: TextStyle(
                fontSize: 12.0,
                color: Colors.black,
              ),
            ),
          );
        }

        if (!EnvironmentManager().isNeedRestart) {
          widgetList.add(
            Text(
              '重启生效',
              style: TextStyle(
                fontSize: 12.0,
                color: Colors.red,
              ),
            ),
          );
        }

        return Directionality(
          textDirection: TextDirection.ltr,
          child: Stack(
            children: [
              child,
              Positioned(
                top: 100.0,
                left: -10.0,
                child: Transform.scale(
                  scale: 0.6,
                  alignment: Alignment.topLeft,
                  child: Container(
                    constraints: BoxConstraints(minWidth: 100.0),
                    decoration: BoxDecoration(
                      borderRadius: BorderRadius.all(Radius.circular(8.0)),
                      color: Colors.red.withOpacity(0.5),
                    ),
                    padding: EdgeInsets.only(
                      left: 25.0,
                      right: 10.0,
                      top: 5.0,
                      bottom: 5.0,
                    ),
                    child: Column(
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: widgetList,
                    ),
                  ),
                ),
              ),
            ],
          ),
        );
      },
    );
  }
}
